async fn subscriber_loop(
gcp: Arc<GcpApiClient>,
config: Config,
armed: Arc<Mutex<ArmedPools>>,
)Expand description
Pulls GKE cluster notifications from the Pub/Sub subscription forever, arming node pools when they start upgrading.
async fn subscriber_loop(
gcp: Arc<GcpApiClient>,
config: Config,
armed: Arc<Mutex<ArmedPools>>,
)Pulls GKE cluster notifications from the Pub/Sub subscription forever, arming node pools when they start upgrading.