async fn maybe_trigger_rollout(
client: &Client,
config: &Config,
last_triggered: &mut BTreeMap<(String, String), Instant>,
namespace: &str,
name: &str,
nodes: &BTreeSet<String>,
) -> Result<(), Error>Expand description
Triggers a forced rollout of the given Materialize instance, unless one is already in progress or was triggered very recently.