async fn scan_loop(
client: Client,
gcp: Arc<GcpApiClient>,
config: Config,
armed: Arc<Mutex<ArmedPools>>,
)Expand description
Polls the armed node pools, and the GKE API for pools that should be armed, triggering rollouts for the instances on pools whose blue nodes have all been cordoned. Never returns.